@@ -27,6 +27,10 @@ def main(args=sys.argv):
         update_warnings()
         from . import inventory_parser
         inventory_parser.handler(args[2:])
+    elif args[1] == 'config':
+        update_warnings()
+        from . import config
+        config.handler(args[2:])
     else:
         from . import execute
         execute.handler(args[1:])
