@@ -1,19 +1,25 @@
+import os
 import sys
 import json
+from contextlib import redirect_stderr, redirect_stdout
 from ansible.parsing.dataloader import DataLoader
 from ansible.inventory.manager import InventoryManager
 
 
 def parse_inventory(path):
-    loader = DataLoader()
-    inventory = InventoryManager(
-        loader=loader,
-        sources=path
-    )
-    data = dict(groups=[], hosts=[])
+    with open(os.devnull, 'w') as fd, redirect_stderr(fd), redirect_stdout(fd):
+        loader = DataLoader()
+        inventory = InventoryManager(
+            loader=loader,
+            sources=path
+        )
+    data = dict(groups=[], hosts=[], vars={})
 
     for group in inventory.groups:
-        if group == 'all' or group == 'ungrouped':
+        if group == 'ungrouped':
+            continue
+        elif group == 'all':
+            data['vars'] = inventory.groups[group].vars
             continue
         group_data = dict(
             name=group,
